/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleworkflow.model;

import java.io.Serializable;

/**
 * <p>
 * Provides details of the <code>ScheduleActivityTaskFailed</code> event.
 * </p>
 */
public class ScheduleActivityTaskFailedEventAttributes implements Serializable,
        Cloneable {

    /**
     * <p>
     * The activity type provided in the <code>ScheduleActivityTask</code>
     * decision that failed.
     * </p>
     */
    private ActivityType activityType;
    /**
     * <p>
     * The activityId provided in the <code>ScheduleActivityTask</code> decision
     * that failed.
     * </p>
     */
    private String activityId;
    /**
     * <p>
     * The cause of the failure. This information is generated by the system and
     * can be useful for diagnostic purposes.
     * </p>
     * <note>If <b>cause</b> is set to OPERATION_NOT_PERMITTED, the decision
     * failed because it lacked sufficient permissions. For details and example
     * IAM policies, see <a href=
     * "http://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html"
     * >Using IAM to Manage Access to Amazon SWF Workflows</a>.</note>
     */
    private String cause;
    /**
     * <p>
     * The ID of the <code>DecisionTaskCompleted</code> event corresponding to
     * the decision that resulted in the scheduling of this activity task. This
     * information can be useful for diagnosing problems by tracing back the
     * chain of events leading up to this event.
     * </p>
     */
    private Long decisionTaskCompletedEventId;

    /**
     * <p>
     * The activity type provided in the <code>ScheduleActivityTask</code>
     * decision that failed.
     * </p>
     * 
     * @param activityType
     *        The activity type provided in the
     *        <code>ScheduleActivityTask</code> decision that failed.
     */

    public void setActivityType(ActivityType activityType) {
        this.activityType = activityType;
    }

    /**
     * <p>
     * The activity type provided in the <code>ScheduleActivityTask</code>
     * decision that failed.
     * </p>
     * 
     * @return The activity type provided in the
     *         <code>ScheduleActivityTask</code> decision that failed.
     */

    public ActivityType getActivityType() {
        return this.activityType;
    }

    /**
     * <p>
     * The activity type provided in the <code>ScheduleActivityTask</code>
     * decision that failed.
     * </p>
     * 
     * @param activityType
     *        The activity type provided in the
     *        <code>ScheduleActivityTask</code> decision that failed.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ScheduleActivityTaskFailedEventAttributes withActivityType(
            ActivityType activityType) {
        setActivityType(activityType);
        return this;
    }

    /**
     * <p>
     * The activityId provided in the <code>ScheduleActivityTask</code> decision
     * that failed.
     * </p>
     * 
     * @param activityId
     *        The activityId provided in the <code>ScheduleActivityTask</code>
     *        decision that failed.
     */

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    /**
     * <p>
     * The activityId provided in the <code>ScheduleActivityTask</code> decision
     * that failed.
     * </p>
     * 
     * @return The activityId provided in the <code>ScheduleActivityTask</code>
     *         decision that failed.
     */

    public String getActivityId() {
        return this.activityId;
    }

    /**
     * <p>
     * The activityId provided in the <code>ScheduleActivityTask</code> decision
     * that failed.
     * </p>
     * 
     * @param activityId
     *        The activityId provided in the <code>ScheduleActivityTask</code>
     *        decision that failed.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ScheduleActivityTaskFailedEventAttributes withActivityId(
            String activityId) {
        setActivityId(activityId);
        return this;
    }

    /**
     * <p>
     * The cause of the failure. This information is generated by the system and
     * can be useful for diagnostic purposes.
     * </p>
     * <note>If <b>cause</b> is set to OPERATION_NOT_PERMITTED, the decision
     * failed because it lacked sufficient permissions. For details and example
     * IAM policies, see <a href=
     * "http://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html"
     * >Using IAM to Manage Access to Amazon SWF Workflows</a>.</note>
     * 
     * @param cause
     *        The cause of the failure. This information is generated by the
     *        system and can be useful for diagnostic purposes.</p> <note>If
     *        <b>cause</b> is set to OPERATION_NOT_PERMITTED, the decision
     *        failed because it lacked sufficient permissions. For details and
     *        example IAM policies, see <a href=
     *        "http://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html"
     *        >Using IAM to Manage Access to Amazon SWF Workflows</a>.
     * @see ScheduleActivityTaskFailedCause
     */

    public void setCause(String cause) {
        this.cause = cause;
    }

    /**
     * <p>
     * The cause of the failure. This information is generated by the system and
     * can be useful for diagnostic purposes.
     * </p>
     * <note>If <b>cause</b> is set to OPERATION_NOT_PERMITTED, the decision
     * failed because it lacked sufficient permissions. For details and example
     * IAM policies, see <a href=
     * "http://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html"
     * >Using IAM to Manage Access to Amazon SWF Workflows</a>.</note>
     * 
     * @return The cause of the failure. This information is generated by the
     *         system and can be useful for diagnostic purposes.</p> <note>If
     *         <b>cause</b> is set to OPERATION_NOT_PERMITTED, the decision
     *         failed because it lacked sufficient permissions. For details and
     *         example IAM policies, see <a href=
     *         "http://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html"
     *         >Using IAM to Manage Access to Amazon SWF Workflows</a>.
     * @see ScheduleActivityTaskFailedCause
     */

    public String getCause() {
        return this.cause;
    }

    /**
     * <p>
     * The cause of the failure. This information is generated by the system and
     * can be useful for diagnostic purposes.
     * </p>
     * <note>If <b>cause</b> is set to OPERATION_NOT_PERMITTED, the decision
     * failed because it lacked sufficient permissions. For details and example
     * IAM policies, see <a href=
     * "http://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html"
     * >Using IAM to Manage Access to Amazon SWF Workflows</a>.</note>
     * 
     * @param cause
     *        The cause of the failure. This information is generated by the
     *        system and can be useful for diagnostic purposes.</p> <note>If
     *        <b>cause</b> is set to OPERATION_NOT_PERMITTED, the decision
     *        failed because it lacked sufficient permissions. For details and
     *        example IAM policies, see <a href=
     *        "http://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html"
     *        >Using IAM to Manage Access to Amazon SWF Workflows</a>.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     * @see ScheduleActivityTaskFailedCause
     */

    public ScheduleActivityTaskFailedEventAttributes withCause(String cause) {
        setCause(cause);
        return this;
    }

    /**
     * <p>
     * The cause of the failure. This information is generated by the system and
     * can be useful for diagnostic purposes.
     * </p>
     * <note>If <b>cause</b> is set to OPERATION_NOT_PERMITTED, the decision
     * failed because it lacked sufficient permissions. For details and example
     * IAM policies, see <a href=
     * "http://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html"
     * >Using IAM to Manage Access to Amazon SWF Workflows</a>.</note>
     * 
     * @param cause
     *        The cause of the failure. This information is generated by the
     *        system and can be useful for diagnostic purposes.</p> <note>If
     *        <b>cause</b> is set to OPERATION_NOT_PERMITTED, the decision
     *        failed because it lacked sufficient permissions. For details and
     *        example IAM policies, see <a href=
     *        "http://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html"
     *        >Using IAM to Manage Access to Amazon SWF Workflows</a>.
     * @see ScheduleActivityTaskFailedCause
     */

    public void setCause(ScheduleActivityTaskFailedCause cause) {
        this.cause = cause.toString();
    }

    /**
     * <p>
     * The cause of the failure. This information is generated by the system and
     * can be useful for diagnostic purposes.
     * </p>
     * <note>If <b>cause</b> is set to OPERATION_NOT_PERMITTED, the decision
     * failed because it lacked sufficient permissions. For details and example
     * IAM policies, see <a href=
     * "http://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html"
     * >Using IAM to Manage Access to Amazon SWF Workflows</a>.</note>
     * 
     * @param cause
     *        The cause of the failure. This information is generated by the
     *        system and can be useful for diagnostic purposes.</p> <note>If
     *        <b>cause</b> is set to OPERATION_NOT_PERMITTED, the decision
     *        failed because it lacked sufficient permissions. For details and
     *        example IAM policies, see <a href=
     *        "http://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html"
     *        >Using IAM to Manage Access to Amazon SWF Workflows</a>.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     * @see ScheduleActivityTaskFailedCause
     */

    public ScheduleActivityTaskFailedEventAttributes withCause(
            ScheduleActivityTaskFailedCause cause) {
        setCause(cause);
        return this;
    }

    /**
     * <p>
     * The ID of the <code>DecisionTaskCompleted</code> event corresponding to
     * the decision that resulted in the scheduling of this activity task. This
     * information can be useful for diagnosing problems by tracing back the
     * chain of events leading up to this event.
     * </p>
     * 
     * @param decisionTaskCompletedEventId
     *        The ID of the <code>DecisionTaskCompleted</code> event
     *        corresponding to the decision that resulted in the scheduling of
     *        this activity task. This information can be useful for diagnosing
     *        problems by tracing back the chain of events leading up to this
     *        event.
     */

    public void setDecisionTaskCompletedEventId(
            Long decisionTaskCompletedEventId) {
        this.decisionTaskCompletedEventId = decisionTaskCompletedEventId;
    }

    /**
     * <p>
     * The ID of the <code>DecisionTaskCompleted</code> event corresponding to
     * the decision that resulted in the scheduling of this activity task. This
     * information can be useful for diagnosing problems by tracing back the
     * chain of events leading up to this event.
     * </p>
     * 
     * @return The ID of the <code>DecisionTaskCompleted</code> event
     *         corresponding to the decision that resulted in the scheduling of
     *         this activity task. This information can be useful for diagnosing
     *         problems by tracing back the chain of events leading up to this
     *         event.
     */

    public Long getDecisionTaskCompletedEventId() {
        return this.decisionTaskCompletedEventId;
    }

    /**
     * <p>
     * The ID of the <code>DecisionTaskCompleted</code> event corresponding to
     * the decision that resulted in the scheduling of this activity task. This
     * information can be useful for diagnosing problems by tracing back the
     * chain of events leading up to this event.
     * </p>
     * 
     * @param decisionTaskCompletedEventId
     *        The ID of the <code>DecisionTaskCompleted</code> event
     *        corresponding to the decision that resulted in the scheduling of
     *        this activity task. This information can be useful for diagnosing
     *        problems by tracing back the chain of events leading up to this
     *        event.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ScheduleActivityTaskFailedEventAttributes withDecisionTaskCompletedEventId(
            Long decisionTaskCompletedEventId) {
        setDecisionTaskCompletedEventId(decisionTaskCompletedEventId);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getActivityType() != null)
            sb.append("ActivityType: " + getActivityType() + ",");
        if (getActivityId() != null)
            sb.append("ActivityId: " + getActivityId() + ",");
        if (getCause() != null)
            sb.append("Cause: " + getCause() + ",");
        if (getDecisionTaskCompletedEventId() != null)
            sb.append("DecisionTaskCompletedEventId: "
                    + getDecisionTaskCompletedEventId());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof ScheduleActivityTaskFailedEventAttributes == false)
            return false;
        ScheduleActivityTaskFailedEventAttributes other = (ScheduleActivityTaskFailedEventAttributes) obj;
        if (other.getActivityType() == null ^ this.getActivityType() == null)
            return false;
        if (other.getActivityType() != null
                && other.getActivityType().equals(this.getActivityType()) == false)
            return false;
        if (other.getActivityId() == null ^ this.getActivityId() == null)
            return false;
        if (other.getActivityId() != null
                && other.getActivityId().equals(this.getActivityId()) == false)
            return false;
        if (other.getCause() == null ^ this.getCause() == null)
            return false;
        if (other.getCause() != null
                && other.getCause().equals(this.getCause()) == false)
            return false;
        if (other.getDecisionTaskCompletedEventId() == null
                ^ this.getDecisionTaskCompletedEventId() == null)
            return false;
        if (other.getDecisionTaskCompletedEventId() != null
                && other.getDecisionTaskCompletedEventId().equals(
                        this.getDecisionTaskCompletedEventId()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime
                * hashCode
                + ((getActivityType() == null) ? 0 : getActivityType()
                        .hashCode());
        hashCode = prime * hashCode
                + ((getActivityId() == null) ? 0 : getActivityId().hashCode());
        hashCode = prime * hashCode
                + ((getCause() == null) ? 0 : getCause().hashCode());
        hashCode = prime
                * hashCode
                + ((getDecisionTaskCompletedEventId() == null) ? 0
                        : getDecisionTaskCompletedEventId().hashCode());
        return hashCode;
    }

    @Override
    public ScheduleActivityTaskFailedEventAttributes clone() {
        try {
            return (ScheduleActivityTaskFailedEventAttributes) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                            + "even though we're Cloneable!", e);
        }
    }
}
